Package: argonDash
Type: Package
Title: Argon Shiny Dashboard Template
Version: 0.2.5
Authors@R: c(
  person("David", "Granjon", email = "dgranjon@ymail.com", role = c("aut", "cre")),
  person(family = "RinteRface", role = "cph"),
  person(family = "Creative Tim", role = c("ctb", "cph"), comment = "Argon theme for Bootstrap 4"))
Maintainer: David Granjon <dgranjon@ymail.com>
Description: Create awesome 'Bootstrap 4' dashboards powered by 'Argon'.
License: GPL-2
Imports: shiny, htmltools, argonR
Suggests: magrittr
URL: https://github.com/RinteRface/argonDash,
        https://rinterface.github.io/argonDash/
BugReports: https://github.com/RinteRface/argonDash/issues
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 2.10)
NeedsCompilation: no
Packaged: 2025-04-12 00:03:15 UTC; davidgranjon
Author: David Granjon [aut, cre],
  RinteRface [cph],
  Creative Tim [ctb, cph] (Argon theme for Bootstrap 4)
Repository: CRAN
Date/Publication: 2025-04-12 04:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 11:32:03 UTC; unix
