argonFooter <- argonDashFooter(
  copyrights = "@Divad Nojnarg, 2025",
  src = "https://github.com/DivadNojnarg",
  argonFooterMenu(
    argonFooterItem("RinteRface", src = "https://github.com/RinteRface"),
    argonFooterItem(
      "argon",
      src = "https://demos.creative-tim.com/argon-design-system/index.html"
    )
  )
)
